==> knative-model-5.1.2-sources.jar: annotations/io/fabric8/knative/sources/v1beta1/PingSourceFluent.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface PingSourceFluent<A extends PingSourceFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public PingSourceFluent.MetadataNested<A> withNewMetadata();
    public PingSourceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public PingSourceFluent.MetadataNested<A> editMetadata();
    public PingSourceFluent.MetadataNested<A> editOrNewMetadata();
    public PingSourceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public PingSourceSpec getSpec();
    public PingSourceSpec buildSpec();
    public A withSpec(PingSourceSpec spec);
    public Boolean hasSpec();
    public PingSourceFluent.SpecNested<A> withNewSpec();
    public PingSourceFluent.SpecNested<A> withNewSpecLike(PingSourceSpec item);
    public PingSourceFluent.SpecNested<A> editSpec();
    public PingSourceFluent.SpecNested<A> editOrNewSpec();
    public PingSourceFluent.SpecNested<A> editOrNewSpecLike(PingSourceSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public PingSourceStatus getStatus();
    public PingSourceStatus buildStatus();
    public A withStatus(PingSourceStatus status);
    public Boolean hasStatus();
    public PingSourceFluent.StatusNested<A> withNewStatus();
    public PingSourceFluent.StatusNested<A> withNewStatusLike(PingSourceStatus item);
    public PingSourceFluent.StatusNested<A> editStatus();
    public PingSourceFluent.StatusNested<A> editOrNewStatus();
    public PingSourceFluent.StatusNested<A> editOrNewStatusLike(PingSourceStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<PingSourceFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PingSourceSpecFluent<PingSourceFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PingSourceStatusFluent<PingSourceFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}

==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/sources/v1beta1/PingSourceFluent.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface PingSourceFluent<A extends PingSourceFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public PingSourceFluent.MetadataNested<A> withNewMetadata();
    public PingSourceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public PingSourceFluent.MetadataNested<A> editMetadata();
    public PingSourceFluent.MetadataNested<A> editOrNewMetadata();
    public PingSourceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public PingSourceSpec getSpec();
    public PingSourceSpec buildSpec();
    public A withSpec(PingSourceSpec spec);
    public Boolean hasSpec();
    public PingSourceFluent.SpecNested<A> withNewSpec();
    public PingSourceFluent.SpecNested<A> withNewSpecLike(PingSourceSpec item);
    public PingSourceFluent.SpecNested<A> editSpec();
    public PingSourceFluent.SpecNested<A> editOrNewSpec();
    public PingSourceFluent.SpecNested<A> editOrNewSpecLike(PingSourceSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public PingSourceStatus getStatus();
    public PingSourceStatus buildStatus();
    public A withStatus(PingSourceStatus status);
    public Boolean hasStatus();
    public PingSourceFluent.StatusNested<A> withNewStatus();
    public PingSourceFluent.StatusNested<A> withNewStatusLike(PingSourceStatus item);
    public PingSourceFluent.StatusNested<A> editStatus();
    public PingSourceFluent.StatusNested<A> editOrNewStatus();
    public PingSourceFluent.StatusNested<A> editOrNewStatusLike(PingSourceStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<PingSourceFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PingSourceSpecFluent<PingSourceFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PingSourceStatusFluent<PingSourceFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
